import time
import board
import busio
import digitalio
import st7585
from adafruit_onewire.bus import OneWireBus
from adafruit_ds18x20 import DS18X20

# Initialize SPI bus and control pins
spi = busio.SPI(board.SCK, MOSI=board.MOSI)
dc = digitalio.DigitalInOut(board.IO0)  # data/command
cs = digitalio.DigitalInOut(board.IO2)  # Chip select
rst = digitalio.DigitalInOut(board.IO1)  # reset

display = st7585.ST7585(spi, dc, cs, rst)
display.bias = 4
display.contrast = 40
# Turn on the Backlight LED
backlight = digitalio.DigitalInOut(board.IO3)  # backlight
backlight.switch_to_output()
backlight.value = True
# Clear display
display.fill(0)
display.show()
display.show_icons()


# Initialize one-wire bus on board pin IO21.
ow_bus = OneWireBus(board.IO21)

# Scan for devices on the bus
devices = ow_bus.scan()

# Create a list of DS18X20 objects
sensors = []
for i, d in enumerate(devices):
    # print("Found sensor {} ROM=0x{}".format(i, d.rom.hex()))
    display.text(d.rom.hex(), 0, i * 16, 1)
    sensor = DS18X20(ow_bus, d)
    sensor.resolution = 12
    sensors.append((i, sensor))
display.show()

# Végtelen ciklus a hőmérséklet mérésekhez
while True:
    for i, sensor in sensors:
        conversion_delay = sensor.start_temperature_read()
        time.sleep(conversion_delay)
        temperature = sensor.temperature
        # Delete line before overwriting it
        display.fill_rect(0, i * 16 + 8, 96, 8, 0)
        display.text(f"Temp: {temperature:.2f}C  ", 0, i * 16 + 8, 1)
    display.show()
    time.sleep(5)
